@@ -123,7 +123,7 @@ fn walk_dir<P: AsRef<std::path::Path>>(path: P) -> Result<walkdir::IntoIter, std
 }
 
 fn compare_by_file_name(a: &walkdir::DirEntry, b: &walkdir::DirEntry) -> std::cmp::Ordering {
-    a.file_name().cmp(&b.file_name())
+    a.file_name().cmp(b.file_name())
 }
 
 impl From<std::io::Error> for DirDiffError {
